/v1/projects/{project_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Project »

# /v1/projects/{project_id}

Contents

- /v1/projects/{project_id}
  - GET /v1/projects/{project_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/projects/{project_id}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /v1/projects/{project_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}

Get project information

### Parameters

- project_id: The UUID of the project

### Response status codes

- 200: Success
- 404: The project doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
location | ✔ | string | Base directory where the project should be created on remote server
path |  | string | Directory of the project on the server
project_id | ✔ | string | Project UUID
temporary | ✔ | boolean | If project is a temporary project

## PUT /v1/projects/{project_id}

Update a project

### Parameters

- project_id: The UUID of the project

### Response status codes

- 200: The project has been updated
- 403: You are not allowed to modify this property
- 404: The project doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
path |  | ['string', 'null'] | Path of the project on the server (work only with --local)
temporary |  | boolean | If project is a temporary project

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
location | ✔ | string | Base directory where the project should be created on remote server
path |  | string | Directory of the project on the server
project_id | ✔ | string | Project UUID
temporary | ✔ | boolean | If project is a temporary project

## DELETE /v1/projects/{project_id}

Delete a project from disk

### Parameters

- project_id: The UUID of the project

### Response status codes

- 404: The project doesn’t exist
- 204: Changes have been written on disk

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Project »